@@ -6,7 +6,7 @@ comboGeneral <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
     isFactor <- is.factor(v)
     CombinatoricsRcpp(v, m, repetition, freqs, lower, upper, constraintFun, 
                       comparisonFun, limitConstraints, TRUE, keepResults,
-                      isFactor, FALSE, FUN, new.env(), Parallel)
+                      isFactor, FALSE, FUN, new.env())
 }
 
 permuteGeneral <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
@@ -17,21 +17,21 @@ permuteGeneral <- function(v, m = NULL, repetition = FALSE, freqs = NULL,
     isFactor <- is.factor(v)
     CombinatoricsRcpp(v, m, repetition, freqs, lower, upper, constraintFun, 
                       comparisonFun, limitConstraints, FALSE, keepResults,
-                      isFactor, FALSE, FUN, new.env(), Parallel)
+                      isFactor, FALSE, FUN, new.env())
 }
 
 comboCount <-  function(v, m = NULL, repetition = FALSE, freqs = NULL) {
     
     CombinatoricsRcpp(v, m, repetition, freqs, NULL,
                       NULL, NULL, NULL, NULL, TRUE, 
-                      FALSE, FALSE, TRUE, NULL, NULL, FALSE)
+                      FALSE, FALSE, TRUE, NULL, NULL)
 }
 
 permuteCount <- function(v, m = NULL, repetition = FALSE, freqs = NULL) {
     
     CombinatoricsRcpp(v, m, repetition, freqs, NULL,
                       NULL, NULL, NULL, NULL, FALSE,
-                      FALSE, FALSE, TRUE, NULL, NULL, FALSE)
+                      FALSE, FALSE, TRUE, NULL, NULL)
 }
 
 comboSample <- function(v, m = NULL, repetition = FALSE,
@@ -41,7 +41,7 @@ comboSample <- function(v, m = NULL, repetition = FALSE,
     isFactor <- is.factor(v)
     if (!is.null(seed)) {set.seed(seed)}
     SampleRcpp(v, m, repetition, freqs, sampleVec, TRUE,
-               isFactor, seed, n, sample, FUN, new.env(), Parallel)
+               isFactor, seed, n, sample, FUN, new.env())
 }
 
 permuteSample <- function(v, m = NULL, repetition = FALSE, 
@@ -51,6 +51,6 @@ permuteSample <- function(v, m = NULL, repetition = FALSE,
     isFactor <- is.factor(v)
     if (!is.null(seed)) {set.seed(seed)}
     SampleRcpp(v, m, repetition, freqs, sampleVec, FALSE,
-               isFactor, seed, n, sample, FUN, new.env(), Parallel)
+               isFactor, seed, n, sample, FUN, new.env())
 }
 
