@@ -5,11 +5,11 @@
 
 template <typename typeMatrix, typename typeVector>
 void PermuteGeneral(int n, int r, typeVector &v, bool repetition, int numRows,
-                    std::vector<int> &z, unsigned long int count,
-                    bool nonTrivial, typeMatrix permuteMatrix) {
+                    std::vector<int> z, int intCount, bool nonTrivial,
+                    typeMatrix permuteMatrix) {
     
     unsigned long int uN = n, uR = r, uRowN = numRows;
-    unsigned long int lastElem = n - 1;
+    unsigned long int lastElem = n - 1, count = intCount;
     unsigned long int lastCol = r - 1, pentultimate = n - 2;
     
     if (repetition) {
@@ -124,15 +124,14 @@ void PermuteGeneral(int n, int r, typeVector &v, bool repetition, int numRows,
 }
 
 template <typename typeMatrix, typename typeVector>
-void MultisetPermutation(int n, int r, typeVector &v, int numRows,
-                         unsigned long int count, std::vector<int> &z,
-                         typeMatrix permuteMatrix) {
+void MultisetPermutation(int n, int r, typeVector &v, int numRows, std::vector<int> &z,
+                         int intCount, typeMatrix permuteMatrix) {
     
     unsigned long int lenFreqs = z.size();
     int *arrPerm = new int[lenFreqs];
     
-    unsigned long int uN = n, numR1 = numRows - 1;
-    unsigned long int uR = r, lastCol = r - 1;
+    unsigned long int uN = n, numR1 = numRows - 1, lastCol = r - 1;
+    unsigned long int uR = r, count = intCount;
     unsigned long int lastElem = lenFreqs - 1;
     
     for (std::size_t j = 0; j < lenFreqs; ++j)
@@ -165,10 +164,10 @@ void MultisetPermutation(int n, int r, typeVector &v, int numRows,
 
 template <typename typeVector>
 void PermutationApplyFun(int n, int r, typeVector &v, bool repetition,
-                         int numRows, bool Multi, std::vector<int> &z,
-                         unsigned long int count, SEXP sexpFun, SEXP rho, SEXP ans) {
+                         int numRows, bool Multi, std::vector<int> z,
+                         int intCount, SEXP sexpFun, SEXP rho, SEXP ans) {
     
-    unsigned long int uR = r, uN = n;
+    unsigned long int uR = r, uN = n, count = intCount;
     unsigned long int lenFreqs = (Multi) ? z.size() : 0;
     typeVector vectorPass(r);
     
