@@ -126,94 +126,6 @@ test_that("permuteSample produces correct results", {
                  permuteSample(75, 10, freqs = rep(1:3, 25), n = 20, seed = 42))
 })
 
-test_that("comboSample produces correct results with Parallel enabled", {
-    
-    set.seed(22)
-    s <- sample(comboCount(30, 15), 10)
-    expect_equal(comboSample(30, 15, sampleVec = s), 
-                 comboSample(30, 15, sampleVec = s, Parallel = TRUE))
-    
-    s <- sample(comboCount(20, 15, TRUE), 10)
-    numVec <- rnorm(20)
-    expect_equal(comboSample(numVec, 15, TRUE, sampleVec = s), 
-                 comboSample(numVec, 15, TRUE, sampleVec = s, Parallel = TRUE))
-    
-    s <- sample(comboCount(20, 15, freqs = rep(1:5, 4)), 10)
-    expect_equal(comboSample(factor(1:20), 15, freqs = rep(1:5, 4), sampleVec = s), 
-                 comboSample(factor(1:20), 15, freqs = rep(1:5, 4), sampleVec = s, Parallel = TRUE))
-    
-    ## Very large results
-    # gmp::urand.bigz(3, as.integer(gmp::log2.bigz(comboCount(100, 20))), seed = 20)
-    # Seed initialisation
-    # Big Integer ('bigz') object of length 3:
-    # [1] 136931241864808444967 54680326409663822768  142980928516518348151
-    s <- c("136931241864808444967", "54680326409663822768", "142980928516518348151")
-    expect_equal(comboSample(100, 20, sampleVec = s), 
-                 comboSample(100, 20, sampleVec = s, Parallel = TRUE))
-    
-    # gmp::urand.bigz(3, as.integer(gmp::log2.bigz(comboCount(100, 15, TRUE))), seed = 40)
-    # Seed initialisation
-    # Big Integer ('bigz') object of length 3:
-    # [1] 342517981843091551 409354738272166611 304475906552740882
-    s <- c("342517981843091551", "409354738272166611", "304475906552740882")
-    numVec <- rnorm(100)
-    expect_equal(comboSample(numVec, 15, TRUE, sampleVec = s), 
-                 comboSample(numVec, 15, TRUE, sampleVec = s, Parallel = TRUE))
-    
-    # gmp::urand.bigz(3, as.integer(gmp::log2.bigz(comboCount(100, 15, freqs = rep(1:10, 10)))), seed = 40)
-    # Seed initialisation
-    # Big Integer ('bigz') object of length 3:
-    # [1] 342517981843091551 409354738272166611 304475906552740882
-    s <- c("342517981843091551", "409354738272166611", "304475906552740882")
-    expect_equal(comboSample(factor(1:100), 15, freqs = rep(1:10, 10), sampleVec = s), 
-                 comboSample(factor(1:100), 15, freqs = rep(1:10, 10), sampleVec = s, Parallel = TRUE))
-})
-
-test_that("permuteSample produces correct results with Parallel enabled", {
-    
-    set.seed(23)
-    s <- sample(permuteCount(20, 10), 10)
-    expect_equal(permuteSample(20, 10, sampleVec = s), 
-                 permuteSample(20, 10, sampleVec = s, Parallel = TRUE))
-    
-    s <- sample(permuteCount(13, 6, TRUE), 10)
-    numVec <- rnorm(13)
-    expect_equal(permuteSample(numVec, 6, TRUE, sampleVec = s), 
-                 permuteSample(numVec, 6, TRUE, sampleVec = s, Parallel = TRUE))
-    
-    s <- sample(permuteCount(15, 8, freqs = rep(1:5, 3)), 10)
-    expect_equal(permuteSample(factor(1:15), 8, freqs = rep(1:5, 3), sampleVec = s), 
-                 permuteSample(factor(1:15), 8, freqs = rep(1:5, 3), sampleVec = s, Parallel = TRUE))
-    
-    ## Very large results
-    # gmp::urand.bigz(3, as.integer(gmp::log2.bigz(permuteCount(50, 20))), seed = 20)
-    # Seed initialisation
-    # Big Integer ('bigz') object of length 3:
-    #     [1] 74801221956888070337370777531431 19072507602256094475863899736873
-    # [3] 9984326726047792473737826351831 
-    s <- c("74801221956888070337370777531431", 
-           "19072507602256094475863899736873", "9984326726047792473737826351831")
-    expect_equal(permuteSample(50, 20, sampleVec = s), 
-                 permuteSample(50, 20, sampleVec = s, Parallel = TRUE))
-    
-    # gmp::urand.bigz(3, as.integer(gmp::log2.bigz(permuteCount(50, 15, TRUE))), seed = 40)
-    # Seed initialisation
-    # Big Integer ('bigz') object of length 3:
-    #     [1] 7115783446248247891390559  11745582437091714041532919 11047288804449421110856026
-    s <- c("7115783446248247891390559", "11745582437091714041532919", "11047288804449421110856026")
-    numVec <- rnorm(50)
-    expect_equal(permuteSample(numVec, 15, TRUE, sampleVec = s), 
-                 permuteSample(numVec, 15, TRUE, sampleVec = s, Parallel = TRUE))
-    
-    # gmp::urand.bigz(3, as.integer(gmp::log2.bigz(permuteCount(50, 10, freqs = rep(1:5, 10)))), seed = 40)
-    # Seed initialisation
-    # Big Integer ('bigz') object of length 3:
-    #     [1] 54287605691379807 49066768082526931 16245530401029138
-    s <- c("54287605691379807", "49066768082526931", "16245530401029138")
-    expect_equal(permuteSample(factor(1:50), 10, freqs = rep(1:5, 10), sampleVec = s), 
-                 permuteSample(factor(1:50), 10, freqs = rep(1:5, 10), sampleVec = s, Parallel = TRUE))
-})
-
 test_that("comboSample produces correct results when FUN is applied", {
     
     num <- comboCount(80, 40) - 10
